@@ -248,7 +248,7 @@ static void gigolo_bookmark_panel_init(GigoloBookmarkPanel *self)
 	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_BOTH_HORIZ);
 	gtk_toolbar_set_icon_size(GTK_TOOLBAR(toolbar), GTK_ICON_SIZE_BUTTON);
 
-	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("gtk-connect",
+	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("network-receive",
 			gtk_toolbar_get_icon_size(GTK_TOOLBAR(toolbar))), NULL);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(toolitem), _("Connect to the selected bookmark"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
@@ -260,7 +260,7 @@ static void gigolo_bookmark_panel_init(GigoloBookmarkPanel *self)
 	gtk_tool_item_set_expand(toolitem, TRUE);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 
-	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("gtk-close",
+	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("window-close",
 			gtk_toolbar_get_icon_size(GTK_TOOLBAR(toolbar))), NULL);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(toolitem), _("Close panel"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
