@@ -25,6 +25,12 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
+#include <gtk/gtk.h>
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#else
+#define GDK_IS_X11_DISPLAY(display) FALSE
+#endif
 
 #include "common.h"
 #include "bookmark.h"
@@ -138,12 +144,15 @@ static void gigolo_window_destroy(GigoloWindow *window)
 		gtk_notebook_get_current_page(GTK_NOTEBOOK(priv->notebook_panel)), NULL);
 
 	gtk_widget_destroy(priv->tree_popup_menu);
-	gtk_widget_destroy(priv->systray_icon_popup_menu);
 	gtk_widget_destroy(priv->swin_treeview);
 	gtk_widget_destroy(priv->swin_iconview);
 	g_object_unref(priv->toolbar);
-	g_object_unref(priv->systray_icon);
-	g_object_unref(priv->systray_icon_popup_menu);
+	if (priv->systray_icon != NULL)
+	{
+		g_object_unref(priv->systray_icon);
+		g_object_unref(priv->systray_icon_popup_menu);
+		gtk_widget_destroy(priv->systray_icon_popup_menu);
+	}
 	g_object_unref(priv->backend_gvfs);
 	priv->backend_gvfs = NULL;
 
@@ -412,8 +421,8 @@ static void about_cb(GtkWidget *widget, GigoloWindow *window)
 		"authors", authors,
 		"logo-icon-name", gigolo_get_application_icon_name(),
 		"comments", _("A simple frontend to easily connect/mount to local and remote filesystems"),
-		"copyright", _("Copyright 2008-2011 Enrico Tröger"),
-		"website", "http://www.uvena.de/gigolo/",
+		"copyright", "Copyright \302\251 2008-2023 The Xfce development team",
+		"website", "https://docs.xfce.org/apps/gigolo/start",
 		"version", VERSION,
 		"translator-credits", _("translator-credits"),
 		"license",  "Copyright 2008-2011 Enrico Tröger <enrico@xfce.org>\n\n"
@@ -435,7 +444,7 @@ static void about_cb(GtkWidget *widget, GigoloWindow *window)
 
 static void help_cb(GtkWidget *widget, G_GNUC_UNUSED GigoloWindow *window)
 {
-	gigolo_show_uri("http://www.uvena.de/gigolo/help.html");
+	gigolo_show_uri("https://docs.xfce.org/apps/gigolo/start");
 }
 
 
@@ -1096,9 +1105,12 @@ static void gigolo_window_show_systray_icon(GigoloWindow *window, gboolean show)
 {
 	GigoloWindowPrivate *priv = gigolo_window_get_instance_private(window);
 
-	G_GNUC_BEGIN_IGNORE_DEPRECATIONS /* Gtk 3.14 */
-	gtk_status_icon_set_visible(priv->systray_icon, show);
-	G_GNUC_END_IGNORE_DEPRECATIONS
+	if (priv->systray_icon != NULL)
+	{
+		G_GNUC_BEGIN_IGNORE_DEPRECATIONS /* Gtk 3.14 */
+		gtk_status_icon_set_visible(priv->systray_icon, show);
+		G_GNUC_END_IGNORE_DEPRECATIONS
+	}
 }
 
 
@@ -1428,7 +1440,8 @@ static void create_ui_elements(GigoloWindow *window)
 	priv->swin_iconview = GTK_WIDGET (gtk_builder_get_object (priv->builder, "swin_iconview"));
 	priv->tree_popup_menu = GTK_WIDGET (gtk_builder_get_object (priv->builder, "tree_popup_menu"));
 	priv->toolbar = GTK_WIDGET (gtk_builder_get_object (priv->builder, "toolbar"));
-	priv->systray_icon_popup_menu = GTK_WIDGET (gtk_builder_get_object (priv->builder, "systray_icon_popup_menu"));
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+		priv->systray_icon_popup_menu = GTK_WIDGET (gtk_builder_get_object (priv->builder, "systray_icon_popup_menu"));
 	priv->notebook_store = GTK_WIDGET (gtk_builder_get_object (priv->builder, "notebook_store"));
 	priv->menubar_bookmarks_menu = gigolo_menu_button_action_new("Bookmarks");
 	priv->systray_bookmarks_menu = gigolo_menu_button_action_new("Bookmarks");
@@ -1663,13 +1676,16 @@ static void gigolo_window_init(GigoloWindow *window)
 	gtk_widget_show_all(priv->swin_iconview);
 
 	/* Status icon */
-	G_GNUC_BEGIN_IGNORE_DEPRECATIONS /* Gtk 3.14 */
-	priv->systray_icon = gtk_status_icon_new_from_icon_name(gigolo_get_application_icon_name());
-	gtk_status_icon_set_tooltip_text(priv->systray_icon, _("Gigolo"));
-	G_GNUC_END_IGNORE_DEPRECATIONS
-	g_signal_connect(priv->systray_icon, "activate", G_CALLBACK(systray_icon_activate_cb), window);
-	g_signal_connect(priv->systray_icon, "popup-menu", G_CALLBACK(systray_icon_popup_menu_cb), window);
-	g_signal_connect(priv->systray_icon, "notify", G_CALLBACK(gigolo_window_systray_notify_cb), window);
+	if (GDK_IS_X11_DISPLAY(gdk_display_get_default()))
+	{
+		G_GNUC_BEGIN_IGNORE_DEPRECATIONS /* Gtk 3.14 */
+		priv->systray_icon = gtk_status_icon_new_from_icon_name(gigolo_get_application_icon_name());
+		gtk_status_icon_set_tooltip_text(priv->systray_icon, _("Gigolo"));
+		G_GNUC_END_IGNORE_DEPRECATIONS
+		g_signal_connect(priv->systray_icon, "activate", G_CALLBACK(systray_icon_activate_cb), window);
+		g_signal_connect(priv->systray_icon, "popup-menu", G_CALLBACK(systray_icon_popup_menu_cb), window);
+		g_signal_connect(priv->systray_icon, "notify", G_CALLBACK(gigolo_window_systray_notify_cb), window);
+	}
 }
 
 
